using System;
using System.Xml;

namespace TopCoder.Uml.Xmi.MetaData
{
    /// <summary>
    /// Represents a UML:TaggedValue node which stores documentation.
    /// </summary>
    /// <author>Dan Manges (Seiz3r)</author>
    public class UmlTaggedValue : XmiElement
    {
        /// <summary>
        /// Reference to the type of documentation.
        /// </summary>
        private string tagDefinitionIdRef;

        /// <summary>
        /// The documentation.
        /// </summary>
        private string value;

        /// <summary>
        /// The documentation type.
        /// </summary>
        private DocumentationType docType;

        /// <summary>
        /// Create a new UmlTaggedValue based on a node from XMI.
        /// </summary>
        /// <param name="node">The node to read data from.</param>
        public UmlTaggedValue(XmlNode node) : base(node)
        {
            foreach (XmlNode childNode in node.ChildNodes)
            {
                if (childNode.Name == "UML:TaggedValue.dataValue")
                {
                    this.value = childNode.InnerText.Trim();
                }
                else if (childNode.Name == "UML:TaggedValue.type")
                {
                    this.tagDefinitionIdRef = Helper.ReadAttribute(childNode.ChildNodes[0], "xmi.idref");
                }
            }
        }

        /// <summary>
        /// Gets or sets the type of documentation.
        /// </summary>
        /// <value>The type of documentation.</value>
        /// <returns>The type of documentation.</returns>
        public DocumentationType DocumentationType
        {
            get
            {
                return this.docType;
            }
            set
            {
                this.docType = value;
            }
        }

        /// <summary>
        /// Gets the referenced documentation type id.
        /// </summary>
        /// <value>The referenced documentation type id.</value>
        /// <returns>The referenced documentation type id.</returns>
        public string TagDefinitionIdRef
        {
            get
            {
                return this.tagDefinitionIdRef;
            }
        }

        /// <summary>
        /// Gets the actual documentation.
        /// </summary>
        /// <returns>The documentation.</returns>
        public string Value
        {
            get
            {
                return this.value;
            }
        }
    }
}